# Split Cluster Return To Tree View

## Upregulated Features (vs Parent)

## Downregulated Features (vs Parent)

## Upregulated Features (vs All)

## Downregulated Features (vs All)

## Upregulated Features (vs Sisters)

## Downregulated Features (vs Sisters)

## Most Improved Features (vs Parent)

##### (Largest Coefficients of Determination per feature)

## Switch Feature Display

Info
Top n features with the largest change in mean value predicted by nodes in this cluster.

## Sister Scores

## Sample Scores

## Switch Score Display

Info
Low-dimensional embedding colored by sample frequency.

- Sample score: probability of encountering sample in a cluster node.
- Sister score: probability of encountering sample in cluster node - probability of encountering sample in sister of a cluster node

## Switch Local/Global

Info
Pairwise correlations of top n changed features.

- Local correlations: correlation weighted by frequency of sample in this cluster and its sisters.
- Global correlations: unweighted correlations of features. (use for comparison to local)

## Cluster Probability Ratio

Info
Probability ratio of a sample encountering THIS node cluster given that it already encountered the OTHER node cluster.
Larger number means THIS cluster depends more on OTHER cluster.
This value sometimes produces counter-intuitive results, be careful interpreting it.